%% Group SDNN, RMSSD and pNN50 values by duration

% group SDNN and RMSSD
for i=1:size(SDNNrefC,1)
    SDNNrefTime(i,:)=[SDNNrefC{i,1:end}];
    SDNNrPPGTime(i,:)=[SDNNrPPGC{i,1:end}]; 
    RMSSDrefTime(i,:)=[RMSSDrefC{i,1:end}];
    RMSSDrPPGTime(i,:)=[RMSSDrPPGC{i,1:end}];
    pNN50refTime(i,:)=[pNN50refC{i,1:end}];
    pNN50rPPGTime(i,:)=[pNN50rPPGC{i,1:end}];
    
    % log values
    logSDNNrefTime(i,:)=log([SDNNrefC{i,1:end}]);
    logSDNNrPPGTime(i,:)=log([SDNNrPPGC{i,1:end}]); 
    logRMSSDrefTime(i,:)=log([RMSSDrefC{i,1:end}]);
    logRMSSDrPPGTime(i,:)=log([RMSSDrPPGC{i,1:end}]);
end

for j=1:size(logSDNNrPPGTime,1)
    MAElnSDNN(j)=sum(abs(logSDNNrPPGTime(j,:)-logSDNNrefTime(8,:)))/length(logSDNNrPPGTime(j,:));
    MAElnRMSSD(j)=sum(abs(logRMSSDrPPGTime(j,:)-logRMSSDrefTime(8,:)))/length(logSDNNrPPGTime(j,:));
end

%% test normal distribution Shapiro-Wilk
for i=1:size(SDNNrPPGTime,1)
    [HSDNN(i), pValueSDNN(i), W(i)] = swtest(SDNNrPPGTime(i,:), 0.05);
    [HRMSSD(i), pValueRMSSD(i), W(i)] = swtest(RMSSDrPPGTime(i,:), 0.05);
    [HpNN50(i), pValuepNN50(i), W(i)] = swtest(pNN50rPPGTime(i,:), 0.05);
    [HlnSDNN(i), pValuelnSDNN(i), Wlog(i)] = swtest(logSDNNrPPGTime(i,:), 0.05);
    [HlnRMMSD(i), pValuelnRMSSD(i), Wlog(i)] = swtest(logRMSSDrPPGTime(i,:), 0.05);
end

%% Correlation analysis - pairwise comparison of recordings of the same length

% parametric
% Pearson coefficient and corresponding p-values
for i=1:size(logSDNNrPPGTime,1)
    [PaersonSDNNtime(i),pvalSDNNtime(i)]=corr(logSDNNrefTime(i,:)',logSDNNrPPGTime(i,:)','Type','Pearson');
end

% non-parametric
% calculate Spearman coefficient and corresponding p-values
for i=1:size(SDNNrPPGTime,1)
    [SpearmanSDNNtimeRaw(i),pvalSDNNtimeRaw(i)]=corr(SDNNrefTime(i,:)',SDNNrPPGTime(i,:)','Type','Spearman');
    [SpearmanRMSSDtimeRaw(i),pvalRMSSDtimeRaw(i)]=corr(RMSSDrefTime(i,:)',RMSSDrPPGTime(i,:)','Type','Spearman');
    [SpearmanpNN50timeRaw(i),pvalpNN50timeRaw(i)]=corr(pNN50refTime(i,:)',pNN50rPPGTime(i,:)','Type','Spearman');
end

filename4='correlationAnalysis.xlsx';
xlswrite(filename4,PaersonSDNNtime,'correlation','A1')
xlswrite(filename4,pvalSDNNtime,'correlation','J1')
xlswrite(filename4,SpearmanSDNNtimeRaw,'correlation','A9')
xlswrite(filename4,SpearmanRMSSDtimeRaw,'correlation','A10')
xlswrite(filename4,SpearmanpNN50timeRaw,'correlation','A11')
xlswrite(filename4,pvalSDNNtimeRaw,'correlation','J9')
xlswrite(filename4,pvalRMSSDtimeRaw,'correlation','J10')
xlswrite(filename4,pvalpNN50timeRaw,'correlation','J11')

%% Correlation analysis - pairwise comparison of 60s PPG recording and rPPG of all the recording lengths

for i=1:size(logSDNNrPPGTime,1)
    [PaersonSDNNtime2(i),pvalSDNNtime2(i)]=corr(logSDNNrefTime(8,:)',logSDNNrPPGTime(i,:)','Type','Pearson');
end

% non-parametric
% calculate Spearman coefficient and corresponding p-values
for i=1:size(SDNNrPPGTime,1)
    [SpearmanSDNNtimeRaw2(i),pvalSDNNtimeRaw2(i)]=corr(SDNNrefTime(8,:)',SDNNrPPGTime(i,:)','Type','Spearman');
    [SpearmanRMSSDtimeRaw2(i),pvalRMSSDtimeRaw2(i)]=corr(RMSSDrefTime(8,:)',RMSSDrPPGTime(i,:)','Type','Spearman');
    [SpearmanpNN50timeRaw2(i),pvalpNN50timeRaw2(i)]=corr(pNN50refTime(8,:)',pNN50rPPGTime(i,:)','Type','Spearman');
end

alpha=0.05;
[corrected_pSDNN, hSDNN]=bonf_holm(pvalSDNNtime2,alpha);
[corrected_pSDNNRaw, hSDNNRaw]=bonf_holm(pvalSDNNtimeRaw2,alpha);
[corrected_pRMSSDRaw, hRMSSDRaw]=bonf_holm(pvalRMSSDtimeRaw2,alpha);
[corrected_ppNN50Raw, hpNN50Raw]=bonf_holm(pvalpNN50timeRaw2(5:8),alpha);

xlswrite('test.xlsx',pvalSDNNtimeRaw2,'Sheet1','A2')
xlswrite('test.xlsx',corrected_pSDNNRaw,'Sheet1','A3')

xlswrite('test.xlsx',pvalSDNNtime2,'Sheet1','A5')
xlswrite('test.xlsx',corrected_pSDNN,'Sheet1','A6')

xlswrite('test.xlsx',pvalRMSSDtimeRaw2,'Sheet1','A8')
xlswrite('test.xlsx',corrected_pRMSSDRaw,'Sheet1','A9')

xlswrite('test.xlsx',pvalpNN50timeRaw2(5:8),'Sheet1','A11')
xlswrite('test.xlsx',corrected_ppNN50Raw,'Sheet1','A12')


%% Effect size

% parametric
% Cohen's d statistic
for i=1:size(logSDNNrPPGTime,1)
    % SDNN
    sdpooled=sqrt(((std(logSDNNrefTime(i,:)))^2+(std(logSDNNrPPGTime(i,:)))^2)/2);
    cohendSDNN(i)=(mean(logSDNNrefTime(i,:))-mean(logSDNNrPPGTime(i,:)))/sdpooled;
end

% non-parametric
% Cliff's delta statistic
for i=1:size(SDNNrPPGTime,1)
    % SDNN
    cliffsSDNN(i)=cliffsDelta(SDNNrefTime(i,:),SDNNrPPGTime(i,:));
    % RMSSD
    cliffsRMSSD(i)=cliffsDelta(RMSSDrefTime(i,:),RMSSDrPPGTime(i,:));
    % pNN50
    cliffspNN50(i)=cliffsDelta(pNN50refTime(i,:),pNN50rPPGTime(i,:));
end

filename4='correlationAnalysis.xlsx';
xlswrite(filename4,cohendSDNN,'effectSize','A1')

xlswrite(filename4,cliffsSDNN,'effectSize','A9')
xlswrite(filename4,cliffsRMSSD,'effectSize','A10')
xlswrite(filename4,cliffspNN50,'effectSize','A11')

% For example, a Cohens d of 1.027 is the difference between two recording
% means of 2.7% of the SD of the total recording could be interpreted as a very small 
% effect (where d = 0.20 is a small, d = 0.50 is a moderate, and d = 0.80 is a large difference)

%% Bland-Altman's statistics

for i=1:8
    % lnSDNN
    diffSDNN=logSDNNrPPGTime(i,:)-logSDNNrefTime(i,:);
    biasSDNN(i)=nanmean(diffSDNN);
    LoALowSDNN(i)=biasSDNN(i)-(1.96*nanstd(diffSDNN));
    LoAUpSDNN(i)=biasSDNN(i)+(1.96*nanstd(diffSDNN));
    outliersSDNN(i)=sum(diffSDNN(:) > LoAUpSDNN(i))+sum(diffSDNN(:) < LoALowSDNN(i));
    % pNN50
    diffpNN50Raw=(pNN50rPPGTime(i,:)-pNN50refTime(i,:));
    biaspNN50Raw(i)=nanmedian(diffpNN50Raw);
    LoALowpNN50Raw(i)=biaspNN50Raw(i)-(1.96*nanstd(diffpNN50Raw));
    LoAUppNN50Raw(i)=biaspNN50Raw(i)+(1.96*nanstd(diffpNN50Raw));
    outlierspNN50(i)=sum(diffpNN50Raw(:) > LoAUppNN50Raw(i))+sum(diffpNN50Raw(:) < LoALowpNN50Raw(i));
    % SDNN raw
    diffSDNNRaw=SDNNrPPGTime(i,:)-SDNNrefTime(i,:);
    biasSDNNRaw(i)=nanmedian(diffSDNNRaw);
    LoALowSDNNRaw(i)=biasSDNNRaw(i)-(1.96*nanstd(diffSDNNRaw));
    LoAUpSDNNRaw(i)=biasSDNNRaw(i)+(1.96*nanstd(diffSDNNRaw));
    outliersSDNNRaw(i)=sum(diffSDNNRaw(:) > LoAUpSDNNRaw(i))+sum(diffSDNNRaw(:) < LoALowSDNNRaw(i));
    % RMSSD raw
    diffRMSSDRaw=RMSSDrPPGTime(i,:)-RMSSDrefTime(i,:);
    biasRMSSDRaw(i)=nanmedian(diffRMSSDRaw);
    LoALowRMSSDRaw(i)=biasRMSSDRaw(i)-(1.96*nanstd(diffRMSSDRaw));
    LoAUpRMSSDRaw(i)=biasRMSSDRaw(i)+(1.96*nanstd(diffRMSSDRaw));
    outliersRMSSDRaw(i)=sum(diffRMSSDRaw(:) > LoAUpRMSSDRaw(i))+sum(diffRMSSDRaw(:) < LoALowRMSSDRaw(i));
end

filename5='blandAltman.xlsx';
% bias
xlswrite(filename5,biasSDNN','BA','A1')
xlswrite(filename5,biasSDNNRaw','BA','A19')
xlswrite(filename5,biasRMSSDRaw','BA','B19')
xlswrite(filename5,biaspNN50Raw','BA','C19')
% upper LoA
xlswrite(filename5,LoALowSDNN','BA','E1')
xlswrite(filename5,LoALowSDNNRaw','BA','E19')
xlswrite(filename5,LoALowRMSSDRaw','BA','F19')
xlswrite(filename5,LoALowpNN50Raw','BA','G19')
% lower LoA
xlswrite(filename5,LoAUpSDNN','BA','I1')
xlswrite(filename5,LoAUpSDNNRaw','BA','I19')
xlswrite(filename5,LoAUpRMSSDRaw','BA','J19')
xlswrite(filename5,LoAUppNN50Raw','BA','K19')
% outliers
xlswrite(filename5,outliersSDNN','BA','A38')
xlswrite(filename5,outliersSDNNRaw','BA','C38')
xlswrite(filename5,outliersRMSSDRaw','BA','D38')
xlswrite(filename5,outlierspNN50','BA','E38')

%%
close all

figure('units','normalized','outerposition',[0 0 1 1],'DefaultAxesFontSize',17,'DefaultAxesPosition', [0.1, 0.1, 0.8, 0.8])

for i=1:8
    subplot(2,2,1)
    plot(i,biasSDNNRaw(i),'Marker','s','MarkerSize',8,'MarkerEdgeColor','b','MarkerFaceColor',[0.5,0.5,0.5])
    hold on
    plot(i,LoALowSDNNRaw(i),'Marker','v','MarkerSize',8,'MarkerFaceColor','k','Color', 'k')
    plot(i,LoAUpSDNNRaw(i),'Marker','^','MarkerSize',8,'MarkerFaceColor','k','Color', 'k')
    plot([i,i],[LoALowSDNNRaw(i),LoAUpSDNNRaw(i)],'Color','k')
end
xlim([0,9])
ylabel('\DeltaSDNN (ms)','FontSize', 28), xlabel('recording group','FontSize', 28)
xticks([0 1 2 3 4 5 6 7 8 9])
xticklabels({'','10s-1','10s-2','10s-3','avg10s','30s-1','30s-2','avg30s','60s',''})
hold on, plot([0:9],zeros(1,10),'--','Color','k')
text(0.4,40,'A','FontSize',28)

for i=1:8
    subplot(2,2,2)
    plot(i,biasSDNN(i),'Marker','s','MarkerSize',8,'MarkerEdgeColor','b','MarkerFaceColor',[0.5,0.5,0.5])
    hold on
    plot(i,LoALowSDNN(i),'Marker','v','MarkerSize',8,'MarkerFaceColor','k','Color', 'k')
    plot(i,LoAUpSDNN(i),'Marker','^','MarkerSize',8,'MarkerFaceColor','k','Color', 'k')
    plot([i,i],[LoALowSDNN(i),LoAUpSDNN(i)],'Color','k')
end
xlim([0,9])
ylabel('\DeltalnSDNN (/)','FontSize', 28), xlabel('recording group','FontSize', 28)
xticks([0 1 2 3 4 5 6 7 8 9])
xticklabels({'','10s-1','10s-2','10s-3','avg10s','30s-1','30s-2','avg30s','60s',''})
hold on, plot([0:9],zeros(1,10),'--','Color','k')
text(0.4,0.8,'B','FontSize',28)

for i=1:8
    subplot(2,2,3)
    plot(i,biasRMSSDRaw(i),'Marker','s','MarkerSize',8,'MarkerEdgeColor','b','MarkerFaceColor',[0.5,0.5,0.5])
    hold on
    plot(i,LoALowRMSSDRaw(i),'Marker','v','MarkerSize',8,'MarkerFaceColor','k','Color', 'k')
    plot(i,LoAUpRMSSDRaw(i),'Marker','^','MarkerSize',8,'MarkerFaceColor','k','Color', 'k')
    plot([i,i],[LoALowRMSSDRaw(i),LoAUpRMSSDRaw(i)],'Color','k')
end
xlim([0,9])
ylabel('\DeltaRMSSD (ms)','FontSize', 28), xlabel('recording group','FontSize', 28)
xticks([0 1 2 3 4 5 6 7 8 9])
xticklabels({'','10s-1','10s-2','10s-3','avg10s','30s-1','30s-2','avg30s','60s',''})
hold on, plot([0:9],zeros(1,10),'--','Color','k')
text(0.4,80,'C','FontSize',28)

for i=1:8
    if i>4
        subplot(2,2,4)
        plot(i,biaspNN50Raw(i),'Marker','s','MarkerSize',8,'MarkerEdgeColor','b','MarkerFaceColor',[0.5,0.5,0.5])
        hold on
        plot(i,LoALowpNN50Raw(i),'Marker','v','MarkerSize',8,'MarkerFaceColor','k','Color', 'k')
        plot(i,LoAUppNN50Raw(i),'Marker','^','MarkerSize',8,'MarkerFaceColor','k','Color', 'k')
        plot([i,i],[LoALowpNN50Raw(i),LoAUppNN50Raw(i)],'Color','k')
    end
end
xlim([4,9])
ylim([-40,40])
ylabel('\DeltapNN50 (%)','FontSize', 28), xlabel('recording group','FontSize', 28)
xticks([4 5 6 7 8 9])
xticklabels({'','30s-1','30s-2','avg30s','60s',''})
hold on, plot([0:9],zeros(1,10),'--','Color','k')
text(4.3,30,'D','FontSize',28)


% matlab2tikz('BAplot.tex')

%%
for i=1:8
    MAESDNNtime(i)=sum(abs(SDNNrefTime(i,:)-SDNNrPPGTime(i,:)))/length(SDNNrefTime(i,:));
    MAERMSSDtime(i)=sum(abs(RMSSDrefTime(i,:)-RMSSDrPPGTime(i,:)))/length(RMSSDrefTime(i,:));
    MAEpNN50time(i)=sum(abs(pNN50refTime(i,:)-pNN50rPPGTime(i,:)))/length(pNN50refTime(i,:));
    MAElnSDNNtime(i)=sum(abs(logSDNNrefTime(i,:)-logSDNNrPPGTime(i,:)))/length(logSDNNrefTime(i,:));
end

%% SDNN BA plot - log-transformed values
sz=200;
figure('units','normalized','outerposition',[0 0 1 1],'DefaultAxesFontSize',19,'DefaultAxesPosition', [0.1, 0.1, 0.8, 0.8])

% SDNN BA plot - raw values

% avg10s
subplot(321)
diffSDNN10Raw=SDNNrPPGTime(4,:)-SDNNrefTime(8,:);
scatter(SDNNrefTime(8,:),diffSDNN10Raw,sz,'x','MarkerEdgeColor','k'); hold on
xlim([0 100])
% plot mean line
plot(xlim, [nanmedian(diffSDNN10Raw),nanmedian(diffSDNN10Raw)],'Color','k'), hold on
% plot lower std line
plot(xlim, [nanmedian(diffSDNN10Raw)-(1.96*nanstd(diffSDNN10Raw)),nanmedian(diffSDNN10Raw)-(1.96*nanstd(diffSDNN10Raw))],'--','Color','k'), hold on
% plot upper std line
plot(xlim, [nanmedian(diffSDNN10Raw)+(1.96*nanstd(diffSDNN10Raw)),nanmedian(diffSDNN10Raw)+(1.96*nanstd(diffSDNN10Raw))],'--','Color','k'), hold on
xlabel('SDNN_{ref} [ms]'), ylabel('\DeltaSDNN [ms]')
text(2.1,39,'A','FontSize',28)
ylim([-60 60])
box on

% avg30s
subplot(323)
diffSDNN30Raw=SDNNrPPGTime(7,:)-SDNNrefTime(8,:);
scatter(SDNNrefTime(8,:),diffSDNN30Raw,sz,'x','MarkerEdgeColor','k'); hold on
xlim([0 100])
% plot mean line
plot(xlim, [nanmedian(diffSDNN30Raw),nanmedian(diffSDNN30Raw)],'Color','k'), hold on
% plot lower std line
plot(xlim, [nanmedian(diffSDNN30Raw)-(1.96*nanstd(diffSDNN30Raw)),nanmedian(diffSDNN30Raw)-(1.96*nanstd(diffSDNN30Raw))],'--','Color','k'), hold on
% plot upper std line
plot(xlim, [nanmedian(diffSDNN30Raw)+(1.96*nanstd(diffSDNN30Raw)),nanmedian(diffSDNN30Raw)+(1.96*nanstd(diffSDNN30Raw))],'--','Color','k'), hold on
xlabel('SDNN_{ref} [ms]'), ylabel('\DeltaSDNN [ms]')
text(2.1,39,'C','FontSize',28)
ylim([-60 60])
box on

% 60s
subplot(325)
diffSDNN60Raw=SDNNrPPGTime(8,:)-SDNNrefTime(8,:);
scatter(SDNNrefTime(8,:),diffSDNN60Raw,sz,'x','MarkerEdgeColor','k'); hold on
xlim([0 100])
% plot mean line
plot(xlim, [nanmedian(diffSDNN60Raw),nanmedian(diffSDNN60Raw)],'Color','k'), hold on
% plot lower std line
plot(xlim, [nanmedian(diffSDNN60Raw)-(1.96*nanstd(diffSDNN60Raw)),nanmedian(diffSDNN60Raw)-(1.96*nanstd(diffSDNN60Raw))],'--','Color','k'), hold on
% plot upper std line
plot(xlim, [nanmedian(diffSDNN60Raw)+(1.96*nanstd(diffSDNN60Raw)),nanmedian(diffSDNN60Raw)+(1.96*nanstd(diffSDNN60Raw))],'--','Color','k'), hold on
xlabel('SDNN_{ref} [ms]'), ylabel('\DeltaSDNN [ms]')
text(2.1,39,'E','FontSize',28)
ylim([-60 60])
box on

% log-transformed data

% avg10s
subplot(322)
diffSDNN10=logSDNNrPPGTime(4,:)-logSDNNrefTime(8,:);
scatter(logSDNNrefTime(8,:),diffSDNN10,sz,'x','MarkerEdgeColor','k'); hold on
xlim([2.5 5])

% plot mean line
plot(xlim, [nanmean(diffSDNN10),nanmean(diffSDNN10)],'Color','k'), hold on
% plot lower std line
plot(xlim, [nanmean(diffSDNN10)-(1.96*nanstd(diffSDNN10)),nanmean(diffSDNN10)-(1.96*nanstd(diffSDNN10))],'--','Color','k'), hold on
% plot upper std line
plot(xlim, [nanmean(diffSDNN10)+(1.96*nanstd(diffSDNN10)),nanmean(diffSDNN10)+(1.96*nanstd(diffSDNN10))],'--','Color','k'), hold on
xlabel('lnSDNN_{ref} [/]'), ylabel('\DeltalnSDNN [/]')
text(2.55,1.05,'B','FontSize',28)
ylim([-1 1.5])
box on

% avg30s
subplot(324)
diffSDNN30=logSDNNrPPGTime(7,:)-logSDNNrefTime(8,:);
scatter(logSDNNrefTime(8,:),diffSDNN30,sz,'x','MarkerEdgeColor','k'); hold on
xlim([2.5 5])

% plot mean line
plot(xlim, [nanmean(diffSDNN30),nanmean(diffSDNN30)],'Color','k'), hold on
% plot lower std line
plot(xlim, [nanmean(diffSDNN30)-(1.96*nanstd(diffSDNN30)),nanmean(diffSDNN30)-(1.96*nanstd(diffSDNN30))],'--','Color','k'), hold on
% plot upper std line
plot(xlim, [nanmean(diffSDNN30)+(1.96*nanstd(diffSDNN30)),nanmean(diffSDNN30)+(1.96*nanstd(diffSDNN30))],'--','Color','k'), hold on
xlabel('lnSDNN_{ref} [/]'), ylabel('\DeltalnSDNN [/]')
text(2.55,1.05,'D','FontSize',28)
ylim([-1 1.5])
box on

% 60s
subplot(326)
diffSDNN60=logSDNNrPPGTime(8,:)-logSDNNrefTime(8,:);
scatter(logSDNNrefTime(8,:),diffSDNN60,sz,'x','MarkerEdgeColor','k'); hold on
xlim([2.5 5])

% plot mean line
plot(xlim, [nanmean(diffSDNN60),nanmean(diffSDNN60)],'Color','k'), hold on
% plot lower std line
plot(xlim, [nanmean(diffSDNN60)-(1.96*nanstd(diffSDNN60)),nanmean(diffSDNN60)-(1.96*nanstd(diffSDNN60))],'--','Color','k'), hold on
% plot upper std line
plot(xlim, [nanmean(diffSDNN60)+(1.96*nanstd(diffSDNN60)),nanmean(diffSDNN60)+(1.96*nanstd(diffSDNN60))],'--','Color','k'), hold on
xlabel('lnSDNN_{ref} [/]'), ylabel('\DeltalnSDNN [/]')
text(2.55,1.05,'F','FontSize',28)
ylim([-1 1.5])
box on

%% RMMSD BA plot
sz=200;
figure('units','normalized','outerposition',[0 0 1 1],'DefaultAxesFontSize',19,'DefaultAxesPosition', [0.1, 0.1, 0.8, 0.8])
% raw RMSSD plots
% avg10s
h(1)=subplot(221);
diffRMSSD10=RMSSDrPPGTime(4,:)-RMSSDrefTime(8,:);
scatter(RMSSDrefTime(8,:),diffRMSSD10,sz,'x','MarkerEdgeColor','k'); hold on
k=find(diffRMSSD10==-Inf | diffRMSSD10==Inf);
for i=1:length(k)
    diffRMSSD10(k)=NaN;
end
xlim([0 100])
% plot mean line
plot(xlim, [nanmedian(diffRMSSD10),nanmedian(diffRMSSD10)],'Color','k'), hold on
% plot lower std line
plot(xlim, [nanmedian(diffRMSSD10)-(1.96*nanstd(diffRMSSD10)),nanmedian(diffRMSSD10)-(1.96*nanstd(diffRMSSD10))],'--','Color','k'), hold on
% plot upper std line
plot(xlim, [nanmedian(diffRMSSD10)+(1.96*nanstd(diffRMSSD10)),nanmedian(diffRMSSD10)+(1.96*nanstd(diffRMSSD10))],'--','Color','k'), hold on
xlabel('RMSSD_{ref} [ms]'), ylabel('\DeltaRMSSD [ms]')
ylim([-116 116])
text(4,87,'A','FontSize',28)
box on

% avg30s
h(2)=subplot(222);
diffRMSSD30=RMSSDrPPGTime(7,:)-RMSSDrefTime(8,:);
scatter(RMSSDrefTime(8,:),diffRMSSD30,sz,'x','MarkerEdgeColor','k'); hold on
k=find(diffRMSSD30==-Inf | diffRMSSD30==Inf);
for i=1:length(k)
    diffRMSSD30(k)=NaN;
end

% plot mean line
plot(xlim, [nanmedian(diffRMSSD30),nanmedian(diffRMSSD30)],'Color','k'), hold on
% plot lower std line
plot(xlim, [nanmedian(diffRMSSD30)-(1.96*nanstd(diffRMSSD30)),nanmedian(diffRMSSD30)-(1.96*nanstd(diffRMSSD30))],'--','Color','k'), hold on
% plot upper std line
plot(xlim, [nanmedian(diffRMSSD30)+(1.96*nanstd(diffRMSSD30)),nanmedian(diffRMSSD30)+(1.96*nanstd(diffRMSSD30))],'--','Color','k'), hold on
xlabel('RMSSD_{ref} [ms]'), ylabel('\DeltaRMSSD [ms]')
ylim([-116 116])
text(4,87,'B','FontSize',28)
box on

% 60s
h(3)=subplot(223);
diffRMSSD60=RMSSDrPPGTime(8,:)-RMSSDrefTime(8,:);
scatter(RMSSDrefTime(8,:),diffRMSSD60,sz,'x','MarkerEdgeColor','k'); hold on
k=find(diffRMSSD60==-Inf | diffRMSSD60==Inf);
for i=1:length(k)
    diffRMSSD60(k)=NaN;
end

% plot mean line
plot(xlim, [nanmedian(diffRMSSD60),nanmedian(diffRMSSD60)],'Color','k'), hold on
% plot lower std line
plot(xlim, [nanmedian(diffRMSSD60)-(1.96*nanstd(diffRMSSD60)),nanmedian(diffRMSSD60)-(1.96*nanstd(diffRMSSD60))],'--','Color','k'), hold on
% plot upper std line
plot(xlim, [nanmedian(diffRMSSD60)+(1.96*nanstd(diffRMSSD60)),nanmedian(diffRMSSD60)+(1.96*nanstd(diffRMSSD60))],'--','Color','k'), hold on
xlabel('RMSSD_{ref} [ms]'), ylabel('\DeltaRMSSD [ms]')
ylim([-116 116])
text(4,87,'C','FontSize',28)
box on
pos = get(h,'Position');
new = mean(cellfun(@(v)v(1),pos(1:2)));
set(h(3),'Position',[new,pos{end}(2:end)]);

%% pNN50 BA plot
sz=400;
figure('units','normalized','outerposition',[0 0 1 1],'DefaultAxesFontSize',25,'DefaultAxesPosition', [0.1, 0.1, 0.8, 0.8])
box on

% plot raw data
subplot(121)
diffpNN5030=(pNN50rPPGTime(7,:))-(pNN50refTime(8,:));
scatter(pNN50refTime(8,:),diffpNN5030,sz,'x','MarkerEdgeColor','k'), hold on
k=find(diffpNN5030==-Inf | diffpNN5030==Inf);
for i=1:length(k)
    diffpNN5030(k)=NaN;
end

% plot mean line
plot(xlim,[nanmedian(diffpNN5030),nanmedian(diffpNN5030)],'Color','k'), hold on
% plot lower std line
plot(xlim,[nanmedian(diffpNN5030)-(1.96*nanstd(diffpNN5030)),nanmedian(diffpNN5030)-(1.96*nanstd(diffpNN5030))],'--','Color','k'), hold on
% plot upper std line
plot(xlim,[nanmedian(diffpNN5030)+(1.96*nanstd(diffpNN5030)),nanmedian(diffpNN5030)+(1.96*nanstd(diffpNN5030))],'--','Color','k'), hold on
xlabel('pNN50_{ref} [%]'), ylabel('\DeltapNN50 [%]'), hold on
text(3,36,'A','FontSize',28)
box on

% plot raw data
subplot(122)
diffpNN5060=(pNN50rPPGTime(8,:))-(pNN50refTime(8,:));
scatter(pNN50refTime(8,:),diffpNN5060,sz,'x','MarkerEdgeColor','k'), hold on
k=find(diffpNN5060==-Inf | diffpNN5060==Inf);
for i=1:length(k)
    diffpNN5060(k)=NaN;
end

% plot mean line
plot(xlim,[nanmedian(diffpNN5060),nanmedian(diffpNN5060)],'Color','k'), hold on
% plot lower std line
plot(xlim,[nanmedian(diffpNN5060)-(1.96*nanstd(diffpNN5060)),nanmedian(diffpNN5060)-(1.96*nanstd(diffpNN5060))],'--','Color','k'), hold on
% plot upper std line
plot(xlim,[nanmedian(diffpNN5060)+(1.96*nanstd(diffpNN5060)),nanmedian(diffpNN5060)+(1.96*nanstd(diffpNN5060))],'--','Color','k'), hold on
ylim([-40 40])
xlabel('pNN50_{ref} [%]'), ylabel('\DeltapNN50 [%]'), hold on
text(3,36,'B','FontSize',28)
box on